changeset 9754:7e9b8823755b

(texinfo-format-scan): Make @- vanish; don't insert -. (texinfo-format-soft-hyphen): New function.
author Richard M. Stallman <rms@gnu.org>
date Sun, 30 Oct 1994 20:05:58 +0000
parents 00144934b449
children 705684b6f2a4
files lisp/textmodes/texinfmt.el
diffstat 1 files changed, 7 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/textmodes/texinfmt.el	Sun Oct 30 10:41:03 1994 +0000
+++ b/lisp/textmodes/texinfmt.el	Sun Oct 30 20:05:58 1994 +0000
@@ -641,7 +641,7 @@
   ;; Scan for @-commands.
   (goto-char (point-min))
   (while (search-forward "@" nil t)
-    (if (looking-at "[@{}^'` *\"?!-]")
+    (if (looking-at "[@{}^'` *\"?!]")
         ;; Handle a few special @-followed-by-one-char commands.
         (if (= (following-char) ?*)
             (progn
@@ -1054,7 +1054,8 @@
     (insert ?\n)))
 
 
-;;; Space controlling commands:  @. and @:   
+;;; Space controlling commands:  @. and @:, and the soft hyphen.
+
 (put '\. 'texinfo-format 'texinfo-format-\.)
 (defun texinfo-format-\. ()
   (texinfo-discard-command)
@@ -1064,6 +1065,10 @@
 (defun texinfo-format-\: ()
   (texinfo-discard-command))
 
+(put '\- 'texinfo-format 'texinfo-format-soft-hyphen)
+(defun texinfo-format-soft-hyphen ()
+  (texinfo-discard-command))
+
 
 ;;; @center, @sp, and @br